@@ -3,10 +3,11 @@ use strict;
 use warnings;
 
 package BSON::Binary;
-# ABSTRACT: Legacy BSON type wrapper for binary data (DEPRECATED)
+# ABSTRACT: Binary data for BSON
 
-use version;
-our $VERSION = 'v0.999.5'; # TRIAL
+our $VERSION = '0.13'; # TRIAL
+
+use overload '""' => \&to_s;
 
 our $TYPE_SIMPLE       = 0x00;
 our $TYPE_BYTES        = 0x02;
@@ -35,43 +36,71 @@ sub type {
     return $_[0]->{type};
 }
 
-# alias for compatibility with BSON::Bytes
-sub subtype {
-    return $_[0]->{type};
-}
-
 sub to_s {
     my $self = shift;
     my @data = @{ $self->data };
     return pack( 'lC*', scalar(@data), $self->type, @data );
 }
 
-use overload '""' => \&to_s;
-
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
 
 =head1 NAME
 
-BSON::Binary - Legacy BSON type wrapper for binary data (DEPRECATED)
+BSON::Binary - Binary data for BSON
 
 =head1 VERSION
 
-version v0.999.5
+version 0.13
+
+=head1 SYNOPSIS
+
+    use BSON;
+
+    my $bin = BSON::Binary->new([1,2,3,4,5,0x67,0x89], 0);
 
 =head1 DESCRIPTION
 
-This module has been deprecated as it was horribly inefficient (unpacking
-binary data to individual single-byte elements of an array!) and had a
-weird API that was not compatible with the existing MongoDB Binary wrapper
-implementation on CPAN.
+This module is needed for L<BSON> and it manages BSON's binary element.
 
-You are strongly encouraged to use L<BSON::Bytes> instead.
+=for Pod::Coverage to_s
 
-=for Pod::Coverage new data type subtype to_s
+=head1 METHODS
+
+=head2 new
+
+Main constructor which takes two parameters: An array reference with 
+binary data and a data type. A string may also be passed as the first parameter, 
+in which case it will be converted to an array ref.
+
+    my $bin = BSON::Binary->new("classic\x20string\0", 0);
+
+The different types are described in the BSON specification. A type is
+one of the following:
+
+    0x00  Binary / Generic
+    0x01  Function
+    0x02  Binary (Old)
+    0x03  UUID
+    0x05  MD5
+    0x80  User defined
+
+=head2 data
+
+Returns an array reference to the contents of the binary data.
+
+=head2 type
+
+Returns the type of the binary data per the BSON specification.
+
+=head1 SEE ALSO
+
+L<BSON>
 
 =head1 AUTHORS
 
@@ -79,25 +108,20 @@ You are strongly encouraged to use L<BSON::Bytes> instead.
 
 =item *
 
-David Golden <david@mongodb.com>
+minimalist <minimalist@lavabit.com>
 
 =item *
 
-Stefan G. <minimalist@lavabit.com>
+David Golden <david@mongodb.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2015 by minimalist and MongoDB, Inc..
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-__END__
-
-
-# vim: set ts=4 sts=4 sw=4 et tw=75:
